"use client"

import { motion } from "framer-motion"
import { Sparkles } from "lucide-react"

export function TokenLogo({ size = "large" }: { size?: "small" | "medium" | "large" }) {
  // Size classes
  const sizeClasses = {
    small: {
      container: "text-2xl md:text-3xl",
      icon: "h-4 w-4 md:h-5 md:w-5",
      underline: "h-0.5",
    },
    medium: {
      container: "text-3xl md:text-5xl",
      icon: "h-6 w-6 md:h-7 md:w-7",
      underline: "h-0.5",
    },
    large: {
      container: "text-5xl md:text-7xl",
      icon: "h-8 w-8 md:h-10 md:w-10",
      underline: "h-1",
    },
  }

  const classes = sizeClasses[size]

  return (
    <div className="relative">
      {/* Glow effect behind the text */}
      <div className="absolute inset-0 blur-lg bg-blue-500/30 rounded-full transform scale-150"></div>

      {/* Main title with animation */}
      <motion.div
        initial={{ scale: 0.9, opacity: 0 }}
        animate={{ scale: 1, opacity: 1 }}
        transition={{ duration: 0.8, type: "spring" }}
        className="relative"
      >
        <h1 className={`${classes.container} font-orbitron font-extrabold text-center tracking-wider`}>
          <span className="inline-flex items-center">
            <Sparkles className={`${classes.icon} mr-2 text-yellow-300`} />
            <span className="bg-clip-text text-transparent bg-gradient-to-r from-blue-300 via-white to-blue-300 drop-shadow-[0_0_15px_rgba(59,130,246,0.8)]">
              THE ONE TOKEN
            </span>
            <Sparkles className={`${classes.icon} ml-2 text-yellow-300`} />
          </span>
        </h1>

        {/* Animated underline */}
        <motion.div
          className={`${classes.underline} bg-gradient-to-r from-transparent via-blue-400 to-transparent mt-2`}
          initial={{ width: 0, opacity: 0 }}
          animate={{ width: "100%", opacity: 1 }}
          transition={{ delay: 0.5, duration: 0.8 }}
        />
      </motion.div>
    </div>
  )
}

